<?php

namespace Drupal\Tests\openid_connect_harid\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that HarID module is loaded and configurable.
 *
 * @group openid_connect_harid
 */
class HarIDClientSettingsTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['openid_connect_harid'];

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * Default theme to use when running tests.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->user = $this->drupalCreateUser(['administer openid connect clients']);
    $this->drupalLogin($this->user);
  }

  /**
   * Tests that administration page loads and has HarID client with settings.
   */
  public function testSettingsHasClient() {
    $this->drupalGet('admin/config/services/openid-connect');
    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->fieldExists('clients_enabled[harid]');
    $this->assertSession()->checkboxNotChecked('clients_enabled[harid]');

    $this->assertSession()->fieldExists('clients[harid][settings][client_id]');
    $this->assertSession()->fieldValueEquals('clients[harid][settings][client_id]', '');

    $this->assertSession()->fieldExists('clients[harid][settings][client_secret]');
    $this->assertSession()->fieldValueEquals('clients[harid][settings][client_secret]', '');

    $this->assertSession()->fieldExists('clients[harid][settings][require_strong_session]');
    $this->assertSession()->checkboxNotChecked('clients[harid][settings][require_strong_session]');

    $this->assertSession()->fieldExists('clients[harid][settings][require_personal_code]');
    $this->assertSession()->checkboxNotChecked('clients[harid][settings][require_personal_code]');

    $this->assertSession()->fieldExists('clients[harid][settings][use_test_idp]');
    $this->assertSession()->checkboxNotChecked('clients[harid][settings][use_test_idp]');
  }

  /**
   * Tests that HarID configuration settings submission works as expected.
   */
  public function testSettingsConfigurationSubmit() {
    $this->drupalGet('admin/config/services/openid-connect');
    $page = $this->getSession()->getPage();
    $page->checkField('clients_enabled[harid]');
    $page->fillField('clients[harid][settings][client_id]', 'client id');
    $page->fillField('clients[harid][settings][client_secret]', 'client secret');
    $page->checkField('clients[harid][settings][require_strong_session]');
    $page->checkField('clients[harid][settings][require_personal_code]');
    $page->checkField('clients[harid][settings][use_test_idp]');
    $page->findButton('Save configuration')->click();
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('admin/config/services/openid-connect');
    $this->assertSession()->checkboxChecked('clients_enabled[harid]');
    $this->assertSession()->fieldValueEquals('clients[harid][settings][client_id]', 'client id');
    $this->assertSession()->fieldValueEquals('clients[harid][settings][client_secret]', 'client secret');
    $this->assertSession()->checkboxChecked('clients[harid][settings][require_strong_session]');
    $this->assertSession()->checkboxChecked('clients[harid][settings][require_personal_code]');
    $this->assertSession()->checkboxChecked('clients[harid][settings][use_test_idp]');
  }

}
